@@ -1,11 +1,16 @@
-//! # Number types
+//! # relp-num
 //!
-//! Different data structures and different algorithms are defined over different spaces. This
-//! module defines those spaces and provides implementations.
+//! Number types for the [RELP](https://crates.io/crates/relp) crate.
 #![feature(asm)]
 #![feature(min_specialization)]
 #![feature(label_break_value)]
 #![feature(trait_alias)]
+#![feature(result_flattening)]
+#![feature(unchecked_math)]
+#![feature(core_intrinsics)]
+#![feature(nonzero_ops)]
+#![feature(const_generics)]
+#![feature(const_evaluatable_checked)]
 
 mod binary;
 pub use binary::Binary;
@@ -17,6 +22,9 @@ mod one;
 pub use one::One;
 
 mod integer;
+pub use integer::factorization::prime::Prime;
+pub use integer::big::Ubig;
+pub use integer::big::NonZeroUbig;
 
 mod non_zero;
 pub use non_zero::NonZero;
@@ -30,6 +38,12 @@ pub use rational::Rational64;
 pub use rational::Rational32;
 pub use rational::Rational16;
 pub use rational::Rational8;
+pub use rational::NonZeroRationalBig;
+pub use rational::NonZeroRational128;
+pub use rational::NonZeroRational64;
+pub use rational::NonZeroRational32;
+pub use rational::NonZeroRational16;
+pub use rational::NonZeroRational8;
 
 mod sign;
 pub use sign::Sign;
@@ -44,4 +58,5 @@ pub use traits::FieldRef;
 pub use traits::OrderedField;
 pub use traits::OrderedFieldRef;
 
+// This re-export is used in macros used to construct rationals in tests.
 pub use num_traits::FromPrimitive;
